PacketParseError

Enum PacketParseError 

pub(crate) enum PacketParseError {
    TooShort,
    LengthMismatch {
        declared: u8,
        actual: usize,
    },
    BadCrc,
}
Errors that can arise while parsing a response frame.

Variants



TooShort

The received slice is shorter than the minimum 4-byte response.



LengthMismatch

The count byte does not match the actual slice length.

Fields

declared: u8

Value of the count byte advertised by the chip.

actual: usize

Number of bytes actually present in the slice.



BadCrc

The trailing CRC does not match a CRC computed over the rest of the frame.