pub(crate) fn parse_response_frame(
frame: &[u8],
) -> Result<ResponseFrame<'_>, PacketParseError>Expand description
Parse a response frame.
frame is the exact slice read from the chip, starting with the count
byte and ending with the two CRC bytes.
Errors
Returns PacketParseError if the frame is too short, has an inconsistent
count byte, or fails CRC verification.